package com.hw.dms.controller;

import java.util.Date;
import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.hw.common.core.constant.SecurityConstants;
import com.hw.dms.domain.DmsBaseMaintStation;
import com.hw.job.api.RemoteJobService;
import com.hw.job.api.domain.SysJob;
import com.hw.job.api.util.CronUtils;
import com.hw.system.api.model.LoginUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.dms.domain.DmsPlanLube;
import com.hw.dms.service.IDmsPlanLubeService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 润滑计划Controller
 *
 * @author Open Platform
 * @date 2024-01-12
 */
@RestController
@RequestMapping("/lube")
public class DmsPlanLubeController extends BaseController
{
    @Autowired
    private IDmsPlanLubeService dmsPlanLubeService;
    @Autowired
    private RemoteJobService remoteJobService;

    /**
     * 查询润滑计划列表
     */
    @RequiresPermissions("dms:lube:list")
    @GetMapping("/list")
    public TableDataInfo list(DmsPlanLube dmsPlanLube)
    {
        startPage();
        List<DmsPlanLube> list = dmsPlanLubeService.selectDmsPlanLubeList(dmsPlanLube);
        return getDataTable(list);
    }

    /**
     * 导出润滑计划列表
     */
    @RequiresPermissions("dms:lube:export")
    @Log(title = "润滑计划", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsPlanLube dmsPlanLube)
    {
        List<DmsPlanLube> list = dmsPlanLubeService.selectDmsPlanLubeList(dmsPlanLube);
        ExcelUtil<DmsPlanLube> util = new ExcelUtil<DmsPlanLube>(DmsPlanLube.class);
        util.exportExcel(response, list, "润滑计划数据");
    }

    /**
     * 获取润滑计划详细信息
     */
    @RequiresPermissions("dms:lube:query")
    @GetMapping(value = "/{planLubeId}")
    public AjaxResult getInfo(@PathVariable("planLubeId") Long planLubeId)
    {
        return success(dmsPlanLubeService.selectDmsPlanLubeByPlanLubeId(planLubeId));
    }

    /**
     * 新增润滑计划
     */
    @RequiresPermissions("dms:lube:add")
    @Log(title = "润滑计划", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsPlanLube dmsPlanLube)
    {
        int i = dmsPlanLubeService.insertDmsPlanLube(dmsPlanLube);
        return toAjax(i);
    }

    /**
     * 修改润滑计划
     */
    @RequiresPermissions("dms:lube:edit")
    @Log(title = "润滑计划", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsPlanLube dmsPlanLube)
    {
        return toAjax(dmsPlanLubeService.updateDmsPlanLube(dmsPlanLube));
    }

    /**
     * 删除润滑计划
     */
    @RequiresPermissions("dms:lube:remove")
    @Log(title = "润滑计划", businessType = BusinessType.DELETE)
	@DeleteMapping("/{planLubeIds}")
    public AjaxResult remove(@PathVariable Long[] planLubeIds)
    {
        return toAjax(dmsPlanLubeService.deleteDmsPlanLubeByPlanLubeIds(planLubeIds));
    }
}
